# `pptestkrzysiekmarut` - My simple first project on PyPi

* OP1
* Op3
* Op2

# Install

```python
pip install pptestkrzysiekmarut 
```

## Usage

```python
from pptestkrzysiekmarut.m_mod_pptest import name as n 

>>> n("Write your name")
Witaj: Name Surname

>>>get_numpy_arr([1, 2, 3, 4, 5])
[1, 2, 3, 4, 5]
```